@@ -1,4 +1,4 @@
-# Copyright 2015-2016 Google Inc. All Rights Reserved.
+# Copyright 2015-2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -39,6 +39,10 @@ def Help():
 def SetGlobalStyle(style):
   """Set a style dict."""
   global _style
+  global _GLOBAL_STYLE_FACTORY
+  factory = _GetStyleFactory(style)
+  if factory:
+    _GLOBAL_STYLE_FACTORY = factory
   _style = style
 
 
@@ -204,8 +208,7 @@ def CreatePEP8Style():
       SPLIT_PENALTY_AFTER_OPENING_BRACKET=30,
       SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT=30,
       SPLIT_PENALTY_BEFORE_IF_EXPR=0,
-      USE_TABS=False
-  )  # yapf: disable
+      USE_TABS=False,)
 
 
 def CreateGoogleStyle():
@@ -226,7 +229,6 @@ def CreateChromiumStyle():
   style['INDENT_WIDTH'] = 2
   style['JOIN_MULTIPLE_LINES'] = False
   style['SPLIT_BEFORE_BITWISE_OPERATOR'] = True
-  style['SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT'] = 0
   return style
 
 
@@ -247,8 +249,21 @@ _STYLE_NAME_TO_FACTORY = dict(
     pep8=CreatePEP8Style,
     chromium=CreateChromiumStyle,
     google=CreateGoogleStyle,
-    facebook=CreateFacebookStyle,
-)  # yapf: disable
+    facebook=CreateFacebookStyle,)
+
+_DEFAULT_STYLE_TO_FACTORY = [
+    (CreateChromiumStyle(), CreateChromiumStyle),
+    (CreateFacebookStyle(), CreateFacebookStyle),
+    (CreateGoogleStyle(), CreateGoogleStyle),
+    (CreatePEP8Style(), CreatePEP8Style),
+]
+
+
+def _GetStyleFactory(style):
+  for def_style, factory in _DEFAULT_STYLE_TO_FACTORY:
+    if style == def_style:
+      return factory
+  return None
 
 
 def _StringListConverter(s):
@@ -260,6 +275,7 @@ def _BoolConverter(s):
   """Option value converter for a boolean."""
   return py3compat.CONFIGPARSER_BOOLEAN_STATES[s.lower()]
 
+
 # Different style options need to have their values interpreted differently when
 # read from the config file. This dict maps an option name to a "converter"
 # function that accepts the string read for the option's value from the file and
@@ -297,8 +313,7 @@ _STYLE_OPTION_VALUE_CONVERTER = dict(
     SPLIT_PENALTY_AFTER_OPENING_BRACKET=int,
     SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT=int,
     SPLIT_PENALTY_BEFORE_IF_EXPR=int,
-    USE_TABS=_BoolConverter
-)  # yapf: disable
+    USE_TABS=_BoolConverter,)
 
 
 def CreateStyleFromConfig(style_config):
@@ -308,7 +323,7 @@ def CreateStyleFromConfig(style_config):
     style_config: either a style name or a file name. The file is expected to
       contain settings. It can have a special BASED_ON_STYLE setting naming the
       style which it derives from. If no such setting is found, it derives from
-      the default style. When style_config is None, the DEFAULT_STYLE_FACTORY
+      the default style. When style_config is None, the _GLOBAL_STYLE_FACTORY
       config is created.
 
   Returns:
@@ -317,17 +332,20 @@ def CreateStyleFromConfig(style_config):
   Raises:
     StyleConfigError: if an unknown style option was encountered.
   """
-  styles = (CreatePEP8Style(), CreateGoogleStyle(), CreateFacebookStyle(),
-            CreateChromiumStyle())
+
+  def GlobalStyles():
+    for style, _ in _DEFAULT_STYLE_TO_FACTORY:
+      yield style
+
   def_style = False
   if style_config is None:
-    for style in styles:
+    for style in GlobalStyles():
       if _style == style:
         def_style = True
         break
     if not def_style:
       return _style
-    return DEFAULT_STYLE_FACTORY()
+    return _GLOBAL_STYLE_FACTORY()
   style_factory = _STYLE_NAME_TO_FACTORY.get(style_config.lower())
   if style_factory is not None:
     return style_factory()
@@ -343,8 +361,8 @@ def CreateStyleFromConfig(style_config):
 def _CreateConfigParserFromConfigString(config_string):
   """Given a config string from the command line, return a config parser."""
   if config_string[0] != '{' or config_string[-1] != '}':
-    raise StyleConfigError("Invalid style dict syntax: '{}'.".format(
-        config_string))
+    raise StyleConfigError(
+        "Invalid style dict syntax: '{}'.".format(config_string))
   config = py3compat.ConfigParser()
   config.add_section('style')
   for key, value in re.findall(r'([a-zA-Z0-9_]+)\s*[:=]\s*([a-zA-Z0-9_]+)',
@@ -357,23 +375,23 @@ def _CreateConfigParserFromConfigFile(config_filename):
   """Read the file and return a ConfigParser object."""
   if not os.path.exists(config_filename):
     # Provide a more meaningful error here.
-    raise StyleConfigError('"{0}" is not a valid style or file path'.format(
-        config_filename))
+    raise StyleConfigError(
+        '"{0}" is not a valid style or file path'.format(config_filename))
   with open(config_filename) as style_file:
     config = py3compat.ConfigParser()
     config.read_file(style_file)
     if config_filename.endswith(SETUP_CONFIG):
       if not config.has_section('yapf'):
-        raise StyleConfigError('Unable to find section [yapf] in {0}'.format(
-            config_filename))
+        raise StyleConfigError(
+            'Unable to find section [yapf] in {0}'.format(config_filename))
     elif config_filename.endswith(LOCAL_STYLE):
       if not config.has_section('style'):
-        raise StyleConfigError('Unable to find section [style] in {0}'.format(
-            config_filename))
+        raise StyleConfigError(
+            'Unable to find section [style] in {0}'.format(config_filename))
     else:
       if not config.has_section('style'):
-        raise StyleConfigError('Unable to find section [style] in {0}'.format(
-            config_filename))
+        raise StyleConfigError(
+            'Unable to find section [style] in {0}'.format(config_filename))
     return config
 
 
@@ -398,7 +416,7 @@ def _CreateStyleFromConfigParser(config):
     based_on = config.get('yapf', 'based_on_style').lower()
     base_style = _STYLE_NAME_TO_FACTORY[based_on]()
   else:
-    base_style = DEFAULT_STYLE_FACTORY()
+    base_style = _GLOBAL_STYLE_FACTORY()
 
   # Read all options specified in the file and update the style.
   for option, value in config.items(section):
@@ -412,14 +430,16 @@ def _CreateStyleFromConfigParser(config):
     try:
       base_style[option] = _STYLE_OPTION_VALUE_CONVERTER[option](value)
     except ValueError:
-      raise StyleConfigError("'{}' is not a valid setting for {}.".format(
-          value, option))
+      raise StyleConfigError(
+          "'{}' is not a valid setting for {}.".format(value, option))
   return base_style
 
+
 # The default style - used if yapf is not invoked without specifically
 # requesting a formatting style.
 DEFAULT_STYLE = 'pep8'
 DEFAULT_STYLE_FACTORY = CreatePEP8Style
+_GLOBAL_STYLE_FACTORY = CreatePEP8Style
 
 # The name of the file to use for global style definition.
 GLOBAL_STYLE = (os.path.join(
@@ -437,4 +457,4 @@ SETUP_CONFIG = 'setup.cfg'
 # Refactor this so that the style is passed around through yapf rather than
 # being global.
 _style = None
-SetGlobalStyle(DEFAULT_STYLE_FACTORY())
+SetGlobalStyle(_GLOBAL_STYLE_FACTORY())
